==> toycars-0.3.0.tar.gz: toycars-0.3.0/src/PacejkaCurve.h <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Zilibowitz on 20/01/05.
 *
 *  This class implements a Pacejka function look up table
 *  using linear interpolation.
 *
 */

#ifndef PACEJKACURVE_H
#define PACEJKACURVE_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <cmath>

class PacejkaCurve
{
public:
				PacejkaCurve(double inD, double inC, double inB, double inE, unsigned short inSamples = 4096, double domainMax = 6.0);
				~PacejkaCurve();
	
	// function is inlined for optimisation
	double operator() (double value)
	{
		double x = fabs(value)*granularity;
		double frac_x = x - floor(x);
		unsigned short i = (unsigned short)(x);
		
		// nb: instead of capping here, an interpolation method
		// using the function's limit would be much nicer.
		if (i >= samples-1)
			return value > 0 ? data[samples-1] : -data[samples-1];
		
		// linearly interpolate using the correct sign for the result
		if (value > 0)
			return (1 - frac_x)*data[i] + frac_x*data[i+1];
		else
			return -(1 - frac_x)*data[i] - frac_x*data[i+1];
	}
	
	double getPeak() { return peak; }
	
	double pacejkaFn(double value);
	
protected:
	double*	data;
	double	granularity;
	unsigned short samples;
	double	D, C, B, E;
	double	peak;
	double	limit;
};

#endif

==> toycars-0.3.3.tar.gz: toycars-0.3.3/src/PacejkaCurve.h <==
/*
	Copyright (C) 2005 by Ruben Henner Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Henner Zilibowitz on 20/01/05.
 *
 *  This class implements a Pacejka function look up table
 *  using linear interpolation.
 *
 */

#ifndef PACEJKACURVE_H
#define PACEJKACURVE_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <cmath>

class PacejkaCurve
{
public:
				PacejkaCurve(double inD, double inC, double inB, double inE, unsigned short inSamples = 4096, double domainMax = 6.0);
				~PacejkaCurve();
	
	// function is inlined for optimisation
	double operator() (double value)
	{
		double x = fabs(value)*granularity;
		double frac_x = x - floor(x);
		unsigned short i = (unsigned short)(x);
		
		// nb: instead of capping here, an interpolation method
		// using the function's limit would be much nicer.
		if (i >= samples-1)
			return value > 0 ? data[samples-1] : -data[samples-1];
		
		// linearly interpolate using the correct sign for the result
		if (value > 0)
			return (1 - frac_x)*data[i] + frac_x*data[i+1];
		else
			return -(1 - frac_x)*data[i] - frac_x*data[i+1];
	}
	
	double getPeak() { return peak; }
	
	double pacejkaFn(double value);
	
protected:
	double*	data;
	double	granularity;
	unsigned short samples;
	double	D, C, B, E;
	double	peak;
	double	limit;
};

#endif
